DownloadItem

Struct DownloadItem 

#[non_exhaustive]
pub struct DownloadItem {
Show 17 fields pub id: DownloadId, pub url: String, pub filename: String, pub state: DownloadState, pub bytes_received: u64, pub total_bytes: Option<u64>, pub file_size: Option<u64>, pub error: Option<String>, pub start_time: String, pub end_time: Option<String>, pub paused: bool, pub can_resume: bool, pub exists: bool, pub mime: Option<String>, pub incognito: bool, pub estimated_end_time: Option<String>, pub danger: Option<String>,
}
Details about a download.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: DownloadId

Browser-assigned download ID.

url: String

The URL that was downloaded.

filename: String

Absolute filesystem path where the file was saved.

state: DownloadState

Current state of the download.

bytes_received: u64

Bytes received so far.

total_bytes: Option<u64>

Total file size in bytes, or None if unknown.

file_size: Option<u64>

Final file size in bytes, or None if unknown.

error: Option<String>

Error reason if the download was interrupted.

start_time: String

ISO 8601 timestamp when the download started.

end_time: Option<String>

ISO 8601 timestamp when the download ended.

paused: bool

Whether the download is paused.

can_resume: bool

Whether an interrupted download can be resumed.

exists: bool

Whether the downloaded file still exists on disk.

mime: Option<String>

MIME type of the downloaded file.

incognito: bool

Whether the download is associated with a private/incognito session.

estimated_end_time: Option<String>

Predicted completion time as an ISO 8601 timestamp string.

danger: Option<String>

Danger classification of the download (e.g. “safe”, “file”, “url”, “uncommon”, “malware”).

Implementations

Source

impl DownloadItem

pub const fn new( id: DownloadId, url: String, filename: String, state: DownloadState, bytes_received: u64, total_bytes: Option<u64>, file_size: Option<u64>, error: Option<String>, start_time: String, end_time: Option<String>, paused: bool, can_resume: bool, exists: bool, mime: Option<String>, incognito: bool, estimated_end_time: Option<String>, danger: Option<String>, ) -> Self

Create a new DownloadItem.